==> ?f=plg_jw_allvideos-v5.0.0_j1.5-3.x.zip: README.md <==
AllVideos
=========

AllVideos (by JoomlaWorks) is truly THE all-in-one media management solution for Joomla and a classic must-have extension for any Joomla based website.

Use the plugin to easily embed video & audio content from all major 3rd party media providers (YouTube, Vimeo, Dailymotion, Facebook, Flickr & SoundCloud) inside your Joomla articles, K2, Virtuemart, Kunena and any other Joomla component that supports "content" plugins.

Additionally, it allows you to playback any web-native video/audio file format hosted on your server or even a remote server, providing great flexibility when it comes to media content embedding. Fun videos, product presentations, audio podcasts, you name it!


## WHY ALLVIDEOS?
- You don't have to copy/paste huge blocks of HTML code, just to get a video from YouTube to playback on your Joomla website. Your WYSIWYG editor in Joomla loves it and so will you and your clients!
- You use simple plugin tags like {youtube}[https://www.youtube.com/watch?v=0u_g6zNuP_I](https://www.youtube.com/watch?v=0u_g6zNuP_I){/youtube} (or just {youtube}0u\_g6zNuP\_I{/youtube}), {mp4}holiday\_in\_rome{/mp4} or {mp3}pixies\_bonemachine{/mp3}.


## FEATURES
1. All major 3rd party media providers are supported: YouTube (single videos & playlists), Vimeo, Dailymotion, Facebook (for videos), Flickr (for videos) & SoundCloud. Use simple plugin tags utilizing the full media page URL (e.g. {youtube}[https://www.youtube.com/watch?v=0u_g6zNuP_I](https://www.youtube.com/watch?v=0u_g6zNuP_I){/youtube}) or just the ID from the media URL page (e.g {youtube}0u\_g6zNuP\_I{/youtube}).
2. Stream your own media content using web-native video and audio formats like H.264/MPEG-4 (.mp4/.m4v/.m4a), WebM (.webm), Ogg Theora Vorbis (.ogg/.ogv/.oga), MP3 (.mp3), WAVE PCM (.wav) & FLAC (.flac), as well as generic containers like .avi & .mkv. For non web-native media embedded with older version of AllVideos (prior to version 5.0.0), which are not supported by modern browsers, a download message will be presented - this basically includes Flash Video (.flv/.f4v), ShockWave Flash (.swf), Windows Media (.wmv/.wma), QuickTime (.mov/.mpg/.mpeg/.3gp/.3g2/.aac), DivX (.divx) etc.
3. Easily embed your media content either directly from your server or a remote server.
4. Use custom poster/preview images for self-hosted or remote video & audio files, or for videos specifically, let AllVideos auto-generate these images from the 5th second of each video.
5. Simple controls inside the plugin's parameters page provide layout consistency on all the videos shown in your Joomla website. Set your preferences in seconds, publish the plugin and you're ready to start embedding media content!
6. Easy, descriptive syntax for media embedding - {format OR provider}filename{/format OR provider}. You can also use syntax like {format OR provider}filename|width|height|autoplay{/format OR provider} (e.g. an "autoplaying" YouTube video with {youtube}he73js82|600|450|1{/youtube}) to display media at different dimensions.
7. Uses MVC templating. Just copy the /tmpl folder included in the plugin, into your Joomla template's /html folder and rename it to "jw_allvideos", then style the output as you wish.
8. Mobile/tablet friendly by default.
9. Includes 3 templates: Classic, Framed and Responsive
10. Fully responsive media playback when using the "Responsive" template.
11. Uses the core Joomla updater (since version 4.5.0).


## COMPATIBILITY
AllVideos is fully compatible with Joomla versions 1.5 to 3.x on servers running PHP 5 or 7.


## LICENSE
AllVideos is a Joomla plugin developed by JoomlaWorks, released under the GNU General Public License.


## LEARN MORE
Visit the AllVideos product page at: https://www.joomlaworks.net/allvideos

==> ?f=plg_jw_allvideos-v5.1.0_j1.5-3.x.zip: README.md <==
AllVideos
=========

AllVideos (by JoomlaWorks) is truly THE all-in-one media management solution for Joomla and a classic must-have extension for any Joomla based website.

Use the plugin to easily embed video & audio content from all major 3rd party media providers (YouTube, Vimeo, Dailymotion, Twitch, Facebook, Flickr & SoundCloud) inside your Joomla articles, K2, Virtuemart, Kunena and any other Joomla component that supports "content" plugins.

Additionally, it allows you to playback any web-native video/audio file format hosted on your server or even a remote server, providing great flexibility when it comes to media content embedding. Fun videos, product presentations, audio podcasts, you name it!


## WHY ALLVIDEOS?
- You don't have to copy/paste huge blocks of HTML code, just to get a video from YouTube to playback on your Joomla website. Your WYSIWYG editor in Joomla loves it and so will you and your clients!
- You use simple plugin tags like {youtube}[https://www.youtube.com/watch?v=0u_g6zNuP_I](https://www.youtube.com/watch?v=0u_g6zNuP_I){/youtube} (or just {youtube}0u\_g6zNuP\_I{/youtube}), {mp4}holiday\_in\_rome{/mp4} or {mp3}pixies\_bonemachine{/mp3}.


## FEATURES
1. All major 3rd party media providers are supported: YouTube (single videos & playlists), Vimeo, Dailymotion, Twitch, Facebook (for videos), Flickr (for videos) & SoundCloud. Use simple plugin tags utilizing the full media page URL (e.g. {youtube}[https://www.youtube.com/watch?v=0u_g6zNuP_I](https://www.youtube.com/watch?v=0u_g6zNuP_I){/youtube}) or just the ID from the media URL page (e.g {youtube}0u\_g6zNuP\_I{/youtube}).
2. Stream your own media content using web-native video and audio formats like H.264/MPEG-4 (.mp4/.m4v/.m4a), WebM (.webm), Ogg Theora Vorbis (.ogg/.ogv/.oga), MP3 (.mp3), WAVE PCM (.wav) & FLAC (.flac), as well as generic containers like .avi & .mkv. For non web-native media embedded with older version of AllVideos (prior to version 5.0.0), which are not supported by modern browsers, a download message will be presented - this basically includes Flash Video (.flv/.f4v), ShockWave Flash (.swf), Windows Media (.wmv/.wma), QuickTime (.mov/.mpg/.mpeg/.3gp/.3g2/.aac), DivX (.divx) etc.
3. Easily embed your media content either directly from your server or a remote server.
4. Use custom poster/preview images for self-hosted or remote video & audio files, or for videos specifically, let AllVideos auto-generate these images from the 5th second of each video.
5. Simple controls inside the plugin's parameters page provide layout consistency on all the videos shown in your Joomla website. Set your preferences in seconds, publish the plugin and you're ready to start embedding media content!
6. Easy, descriptive syntax for media embedding - {format OR provider}filename{/format OR provider}. You can also use syntax like {format OR provider}filename|width|height|autoplay{/format OR provider} (e.g. an "autoplaying" YouTube video with {youtube}he73js82|600|450|1{/youtube}) to display media at different dimensions.
7. Uses MVC templating. Just copy the /tmpl folder included in the plugin, into your Joomla template's /html folder and rename it to "jw_allvideos", then style the output as you wish.
8. Mobile/tablet friendly by default.
9. Includes 3 templates: Classic, Framed and Responsive
10. Fully responsive media playback when using the "Responsive" template.
11. Uses the core Joomla updater (since version 4.5.0).


## COMPATIBILITY
AllVideos is fully compatible with Joomla versions 1.5 to 3.x on servers running PHP 5 or 7.


## LICENSE
AllVideos is a Joomla plugin developed by JoomlaWorks, released under the GNU General Public License.


## LEARN MORE
Visit the AllVideos product page at: https://www.joomlaworks.net/allvideos

Last update: August 22nd, 2019 - Version 5.1.0
